@@ -25,7 +25,6 @@
 
 #include "eog-thumb-view.h"
 #include "eog-list-store.h"
-#include "eog-pixbuf-cell-renderer.h"
 #include "eog-image.h"
 #include "eog-job-queue.h"
 
@@ -60,11 +59,6 @@ struct _EogThumbViewPrivate {
 
 /* Drag 'n Drop */
 
-static GtkTargetEntry target_table[] = {
-	{ "text/uri-list", 0, 0},
-};
-
-
 static void
 eog_thumb_view_finalize (GObject *object)
 {
@@ -433,8 +427,6 @@ thumbview_get_tooltip_string (EogImage *image)
 static void
 on_data_loaded_cb (EogJob *job, gpointer data)
 {
-	GtkWidget *widget = GTK_WIDGET (data);
-
 	if (!job->error) {
 		gtk_tooltip_trigger_tooltip_query (gdk_display_get_default());
 	}
@@ -505,9 +497,15 @@ thumbview_on_query_tooltip_cb (GtkWidget  *widget,
 static void
 eog_thumb_view_init (EogThumbView *thumbview)
 {
+#if !GTK_CHECK_VERSION (2, 15, 0)
+	const GtkTargetEntry target_table[] = {
+		{"text/uri-list", 0, 0 }
+	};
+#endif
+
 	thumbview->priv = EOG_THUMB_VIEW_GET_PRIVATE (thumbview);
 
-	thumbview->priv->pixbuf_cell = eog_pixbuf_cell_renderer_new ();
+	thumbview->priv->pixbuf_cell = gtk_cell_renderer_pixbuf_new ();
 
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (thumbview),
 	      	  		    thumbview->priv->pixbuf_cell,
@@ -549,9 +547,16 @@ eog_thumb_view_init (EogThumbView *thumbview)
 	g_signal_connect (G_OBJECT (thumbview), "parent-set",
 			  G_CALLBACK (thumbview_on_parent_set_cb), NULL);
 
+#if GTK_CHECK_VERSION (2, 15, 0)
+	gtk_icon_view_enable_model_drag_source (GTK_ICON_VIEW (thumbview), 0,
+						NULL, 0,
+						GDK_ACTION_COPY);
+	gtk_drag_source_add_uri_targets (GTK_WIDGET (thumbview));
+#else
 	gtk_icon_view_enable_model_drag_source (GTK_ICON_VIEW (thumbview), 0,
 						target_table, G_N_ELEMENTS (target_table),
 						GDK_ACTION_COPY);
+#endif /* GTK >= 2.15.0 */
 
 	g_signal_connect (G_OBJECT (thumbview), "drag-data-get",
 			  G_CALLBACK (thumbview_on_drag_data_get_cb), NULL);
